#!/usr/bin/env python
# -*- coding: utf-8 -*-

'''
THIS FILE IS PART OF AZUR LANE TOOL BY MATT BELFAST BROWN
mode_BlP_Cal.py - The core mode of the Azur Lane Tool.

Author:Matt Belfast Brown 
Creat Date:2021-07-10
Version Date:2022-01-21
Version:0.4.8
Mode Create Date:2020-05-02
Mode Date:2022-01-21
Mode Version:1.0.2

THIS PROGRAM IS FREE FOR EVERYONE,IS LICENSED UNDER GPL-3.0
YOU SHOULD HAVE RECEIVED A COPY OF GPL-3.0 LICENSE.

Copyright (C) 2021-2022 Matt Belfast Brown

This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program.  If not, see <http://www.gnu.org/licenses/>.
'''

#define import list
    #Null

def fun_cnbp_rqub (vari_plle) :
    #最高方案类型
    if 1 <= vari_plle <= 4 or 6 <= vari_plle <= 9 or 11 <= vari_plle <= 14 :
        vari_bprb = 0.4 * vari_plle - 0.4* ( vari_plle % 5 ) + 2
    elif 16 <= vari_plle <= 19 or 21 <= vari_plle<= 24 or 26 <= vari_plle <= 29 :
        vari_bprb = vari_plle - ( vari_plle % 5) - 5
    elif vari_plle == 5:
        vari_bprb = 5 
    elif vari_plle % 5 ==0:
        vari_bprb =int ( -(vari_plle ** 3 ) / 375 + ( vari_plle ** 2 ) / 5 - 2.9333 * vari_plle +20 )
    return vari_bprb  #升一级所需基础蓝图数量

def fun_cnbp_rqup (flag_pltp,vari_plle):
    if flag_pltp =='Top Solution':
        #最高方案
        vari_bprq = fun_cnbp_rqub(vari_plle)
    elif flag_pltp == 'Decisive Plan' :
        #决战方案
        vari_bprq = int(fun_cnbp_rqub(vari_plle)*1.5)  #最高方案类的1.5倍，并向下取整
    return vari_bprq  #升一级所需蓝图数量

def fun_cnbp_rrcl(flag_pltp,vari_plde,vari_epbp):
    vari_tbpr=0
    vari_tebp=0
    for para_plle in range (vari_lede):
        vari_tbpr+=fun_cnbp_rqup(flag_pltp,para_leve)
    for para_plee in range (vari_levn):
        vari_tebp+=fun_cnbp_rqup(flag_pltp,para_leex)
    vari_tebp+=vari_epbp
    vari_prbp=vari_tbpr-vari_tebp
    return vari_prbp,vari_tebp  #科研图纸需求计算结果 已用的总蓝图数

def fun_cnbp_tyfi(flag_pltp,vari_tfdl,vari_tyfg,vari_crtf):
    vari_bpty=0
    if flag_pltp == 'Top Solution' :
        for i in range(x):
            vari_bpty+=list_fitt[i]
        vari_bpty+=int((vari_crtf/100)*list_fitt[x])
        vari_tbtf=165-vari_bpty
    elif flag_pltp == 'Decisive Plan' :
        for i in range(x):
            vari_bpty+=list_fitd[i]
        vari_bpty+=int((vari_crtf/100)*list_fitt[x])
        vari_tbtf=215-vari_bpty   
    return vari_tbtf,vari_bpty  #天运拟合总需蓝图数  天运拟合总用蓝图数
    
def fun_cnbp_rbpt(flag_pltp,flag_pftf,vari_plde,vari_epbp,vari_tfdl,vari_tyfg,vari_crtf):
    if flag_pftf == True:
        vari_tbtf,vari_bpty=fun_cnbp_tyfi(flag_pltp,vari_tfdl,vari_tyfg,vari_crtf)
    elif flag_pftf == False:
        vari_tbtf,vari_bpty=0,0
    vari_prbp,vari_tebp=fun_cnbp_rrcl(flag_pltp,vari_plde,vari_epbp)
    vari_prbt=vari_prbp+vari_tbtf
    vari_tbpt=vari_tebp+vari_bpty
    return [vari_prbt,vari_tbpt,vari_prbp,vari_tebp,vari_tbtf,vari_bpty]#[科研图纸需求含天运拟合,已用的总蓝图数含天运拟合,科研图纸需求计算结果,已用的总蓝图数,天运拟合总需蓝图数,天运拟合总用蓝图数]
    
#define list
list_fitt=[10,20,30,40,65]
list_fitd=[20,30,40,50,75]


#!/usr/bin/env python
# -*- coding: utf-8 -*-

'''
THIS FILE IS PART OF AZUR LANE TOOL BY MATT BELFAST BROWN
mode_KSN_Com.py - The core mode of the Azur Lane Tool.

Author:Matt Belfast Brown 
Create Date:2021-07-10
Version Date:2022-01-21
Version:0.4.8
Mode Create Date:2020-10-07
Mode Date:2022-01-21
Mode Version:0.8.0

THIS PROGRAM IS FREE FOR EVERYONE,IS LICENSED UNDER GPL-3.0
YOU SHOULD HAVE RECEIVED A COPY OF GPL-3.0 LICENSE.

Copyright (C) 2021-2022 Matt Belfast Brown

This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program.  If not, see <http://www.gnu.org/licenses/>.
'''
'''
#define variable name
  variable-name chinese
  vari_ksip     变量-输入的查询量
  list_ksnc     列表-舰船代码
  list_ksnm     列表-舰船原名
  vari_knrs     变量-查询结果
  para_lsor     参量-列表顺序码
  fun_jpkn_nmco 函数-重樱舰船对照

'''
#define import list
    #Null

#define function
def fun_ksen_nmco(vari_ksip):
    if vari_ksip not in list_ksnc+list_ksnm:
        vari_knrs='查找内容无效，请检验输入内容，或检查更新！'
    else:
        for para_lsor in range(len(list_ksnm)):
            if vari_ksip == list_ksnm[para_lsor]:
                vari_knrs='舰船名：'+vari_ksip+'，对应代号:'+list_ksnc[para_lsor]
            elif vari_ksip == list_ksnc[para_lsor]:
                vari_knrs='舰船名：'+list_ksnm[para_lsor]+'，对应代号:'+vari_ksip
    return vari_knrs  #查询结果

#define list
list_ksnm=['峰风','神风','朝风','春风','松风','旗风','追风','夕凪','睦月','如月','卯月','水无月','文月','长月','三日月','吹雪','白雪','初雪','深雪','浦波','绫波','敷波','曙','涟','潮','晓','响','雷','电','初春','若叶','初霜','有明','夕暮','白露','时雨','夕立','海风','山风','江风','凉风','朝潮','大潮','满潮','荒潮','霞','阳炎','不知火','黑潮','亲潮','初风','雪风','天津风','浦风','矶风','滨风','谷风','野分','岚','萩风','舞风','夕云','卷云','风云','长波','卷波','清波','秋月','初月','凉月','新月JP','冬月','春月','宵月','满月','花月','岛风','樫野','天龙','龙田','球磨','北上','大井','长良','五十铃','由良','鬼怒','阿武隈','夕张','川内','神通','那珂','阿贺野','能代','矢矧','大淀','古鹰','加古','青叶','衣笠','最上','三隈','铃谷','熊野','利根','筑摩','妙高','那智','足柄','羽黑','高雄','爱宕','摩耶','鸟海','金刚','比叡','榛名','雾岛','天城','敷岛','三笠','扶桑','山城','伊势','日向','长门','陆奥','土佐','纪伊','骏河','大和','武藏','凤翔','龙骧','祥凤','瑞凤','千岁','千代田','大鲸','龙凤','飞鹰','隼鹰','赤城','加贺','苍龙','飞龙','翔鹤','瑞鹤','大凤','云龙','葛城','信浓','白龙','明石','伊吹','出云','北风','吾妻','伊9','伊13','伊16','伊19','伊25','伊26','伊54','伊56','伊58','伊60','伊168','伊490','新泽西','提康德罗加','博伊西','旧金山','射水鱼','莫里森']
list_ksnc=['樱','榊','櫂','橪','棡','樋','椎','枳','松','樟','楙','杌','橗','枨','檧','桐','杉','杨','梧','朴','柚','柿','棪','槿','槟','枫','栀','梓','柏','梅','楉','檨','榎','棭','梿','栴','椿','菪','杣','茳','莨','棹','荙','樠','栘','蕸','萩','蒲','蓉','藮','菙','莲','菡','槆','柉','樇','栭','苓','萍','莵','蒠','茭','荨','枟','苌','棬','棈','椛','檚','栎','枥','㮔','桸','楛','槾','榵','芒','㭴','豺','豹','熊','狸','獾','貊','貉','㹨','猤','貃','狐','貆','貎','豻','豼','貅','貁','淀','狼','狌','犹','猅','猨','狻','狺','猁','猑','狘','獌','狏','狳','犰','獒','犬','犮','猋','鲤','鲟','鲑','鳗','鳐','鲙','鲐','魟','鲼','鳌','螯','鲨','鲛','䲠','鲣','鲪','鲸','鳄','凤','枭','鹞','鹳','鹂','鹃','迖','鸗','鸱','鸢','凰','鸾','蛟','龙','鹬','鹤','鹩','靇','鹖','鵗','鹫','茗','峦','侌','苝','猉','玖','十纱','伊知梦','衣玖','双叶檎','双叶梦','冴诗','冴梦','冴矢','六重','伊吕波','诗玖玲','花园','卡莉永','树城','雾城','喷水鱼','赛普拉斯']


#!/usr/bin/env python
# -*- coding: utf-8 -*-

'''
THIS FILE IS PART OF AZUR LANE TOOL BY MATT BELFAST BROWN
__init__.py - The core part of the Azur Lane Tool.

Author: Matt Belfast Brown 
Creat Date:2021-07-10
Version Date:2022-01-21
Version:0.4.8


THIS PROGRAM IS FREE FOR EVERYONE,IS LICENSED UNDER GPL-3.0
YOU SHOULD HAVE RECEIVED A COPY OF GPL-3.0 LICENSE.

Copyright (C) 2021-2022 Matt Belfast Brown

This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program.  If not, see <http://www.gnu.org/licenses/>.
'''
'''
Variable declaration

'''
#import list
import math
import AzurLaneToolLib.mode.mode_EXP_Cal as mode_EXP_Cal
import AzurLaneToolLib.mode.mode_BlP_Cal as mode_BlP_Cal
import AzurLaneToolLib.mode.mode_KSN_Com as mode_KSN_Com
import AzurLaneToolLib.mode.mode_CME_Cal as mode_CME_Cal
import AzurLaneToolLib.mode.mode_FCS_Cal as mode_FCS_Cal

#information list
__title__ = 'AzurLaneToolLib'
__version__ = '0.4.8'
__author__ = 'Matt Belfast Brown'
__license__ = 'GPL-3.0'
__copyright__ = 'Copyright (c) 2020-2022 Matt Belfast Brown'
__all__ = ['mode',
    'mode_EXP_Cal','mode_BlP_Cal','mode_KSN_Com','mode_FCS_Cal','mode_CME_Cal']

#function list
fun_cexp_vrfu=mode_EXP_Cal.fun_cexp_vrfu
fun_crex_cele=mode_EXP_Cal.fun_crex_cele
fun_cnbp_rqup=mode_BlP_Cal.fun_cnbp_rqup
fun_cnbp_rqub=mode_BlP_Cal.fun_cnbp_rqub
fun_cnbp_rrcl=mode_BlP_Cal.fun_cnbp_rrcl
fun_cnbp_tyfi=mode_BlP_Cal.fun_cnbp_tyfi
fun_cnbp_rbpt=mode_BlP_Cal.fun_cnbp_rbpt
fun_ksen_nmco=mode_KSN_Com.fun_ksen_nmco
fun_berf_cmug=mode_CME_Cal.fun_berf_cmug
fun_evdb_cmul=mode_CME_Cal.fun_evdb_cmul


#!/usr/bin/env python
# -*- coding: utf-8 -*-

'''
THIS FILE IS Mode OF AZUR LANE TOOL BY MATT BELFAST BROWN
mode_CME_Cal.py - The core mode of the Azur Lane Tool.

Author:Matt Belfast Brown 
Create Date:2021-07-10
Version Date:2022-01-21
Version:0.4.8
Mode Create Date:2019-08-10
Mode Date:2022-01-21
Mode Version:0.3.0

THIS PROGRAM IS FREE FOR EVERYONE,IS LICENSED UNDER GPL-3.0
YOU SHOULD HAVE RECEIVED A COPY OF GPL-3.0 LICENSE.

Copyright (C) 2021-2022 Matt Belfast Brown

This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A ModeICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program.  If not, see <http://www.gnu.org/licenses/>.
'''

#define import list
    #Null


#define function
def fun_evdb_cmul(vari_cmlv):
    if vari_cmlv==1:
        vari_cler=1
    elif 2<=vari_cmlv<=50:
        vari_cler=(vari_cmlv+1)//3
    elif 51<=vari_cmlv<=70:
        vari_cler=(vari_cmlv+1)//2
    elif 71<=vari_cmlv<=90:
        vari_cler=vari_cmlv+1
    elif 91<=vari_cmlv<=110:
        vari_cler=(vari_cmlv+1)*2
    elif 111<=vari_cmlv<=120:
        vari_cler=(vari_cmlv+1)*3
    elif 121<=vari_cmlv<=130:
        vari_cler=3*vari_cmlv
    elif 131<=vari_cmlv<=150:
        vari_cler=4*vari_cmlv
    elif 151<=vari_cmlv<=170:
        vari_cler=5*vari_cmlv
    elif 171<=vari_cmlv<=190:
        vari_cler=6*vari_cmlv
    elif 191<=vari_cmlv<200:
        vari_cler=7*vari_cmlv
    else:
        vari_cler=0
    vari_cler=int(vari_cler)
    return vari_cler
    
def fun_berf_cmug(vari_cmlv):
    para_cmex=40
    vari_cmex=0
    for para_cmlv in range(1,vari_cmlv+1):
        para_cmle=fun_evdb_cmul(para_cmlv)
        para_cmex=para_cmex+10*para_cmle
        vari_cmex=vari_cmex+para_cmex
    return vari_cmex


#!/usr/bin/env python
# -*- coding: utf-8 -*-

'''
THIS FILE IS PART OF AZUR LANE TOOL BY MATT BELFAST BROWN
mode_EXP_Cal.py - The core mode of the Azur Lane Tool.

Author:Matt Belfast Brown 
Create Date:2021-07-10
Version Date:2022-01-21
Version:0.4.8
Mode Create Date:2020-09-25
Mode Date:2022-01-21
Mode Version:0.4.0

THIS PROGRAM IS FREE FOR EVERYONE,IS LICENSED UNDER GPL-3.0
YOU SHOULD HAVE RECEIVED A COPY OF GPL-3.0 LICENSE.

Copyright (C) 2021-2022 Matt Belfast Brown

This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program.  If not, see <http://www.gnu.org/licenses/>.
'''

'''
#define function
 y=kx+b and k=da and b=mn
 m=-100 n=1000
 a and n are in function fun_cexp_vrfu
'''

#define import list
    #Null

#define function
def fun_cexp_vrfu(flag_kstp,vari_leve):
    if flag_kstp=='Top Solution':
        if vari_leve==0:
            vari_vara=0
            vari_inva=0
        elif vari_leve>0 and vari_leve<=40:
            vari_vara=0.1
            vari_inva=0
        elif vari_leve>40 and vari_leve<=60:
            vari_vara=0.2
            vari_inva=40
        elif vari_leve>60 and vari_leve<=70:
            vari_vara=0.3
            vari_inva=100
        elif vari_leve>70 and vari_leve<=80:
            vari_vara=0.4
            vari_inva=170
        elif vari_leve>80 and vari_leve<=90:
            vari_vara=0.5
            vari_inva=250
        elif vari_leve>90 and vari_leve<=92:
            vari_vara=1
            vari_inva=700
        elif vari_leve>92 and vari_leve<=94:
            vari_vara=2
            vari_inva=1620
        elif vari_leve==95:
            vari_vara=4
            vari_inva=3500
        elif vari_leve>95 and vari_leve<=97:
            vari_vara=5
            vari_inva=4450
        elif vari_leve==98:
            vari_vara=20
            vari_inva=19000
        elif vari_leve==99:
            vari_vara=72
            vari_inva=69960
        elif vari_leve==100:
            vari_vara=-82
            vari_inva=-82500
        elif vari_leve>100 and vari_leve<=105:
            vari_vara=3
            vari_inva=2500
        elif vari_leve>105 and vari_leve<=110:
            vari_vara=6
            vari_inva=5650
        elif vari_leve>110 and vari_leve<=115:
            vari_vara=10
            vari_inva=10050
        elif vari_leve>115 and vari_leve<=120:
            vari_vara=15
            vari_inva=15800
        elif vari_leve>120 and vari_leve<125:
            vari_vara=21
            vari_inva=23000
        elif vari_leve==125:
            vari_vara=2696
            vari_inva=3340000
    elif flag_kstp=='Decisive Plan':
        if vari_leve==0:
            vari_vara=0
            vari_inva=0
        elif vari_leve>0 and vari_leve<=40:
            vari_vara=0.12
            vari_inva=0
        elif vari_leve>40 and vari_leve<=60:
            vari_vara=0.24
            vari_inva=48
        elif vari_leve>60 and vari_leve<=70:
            vari_vara=0.36
            vari_inva=120
        elif vari_leve>70 and vari_leve<=80:
            vari_vara=0.48
            vari_inva=204
        elif vari_leve>80 and vari_leve<90:
            vari_vara=0.6
            vari_inva=300
        elif vari_leve==90:
            vari_vara=0.65
            vari_inva=325
        elif vari_leve>90 and vari_leve<=92:
            vari_vara=1.3
            vari_inva=910
        elif vari_leve>92 and vari_leve<=94:
            vari_vara=2.6
            vari_inva=2106
        elif vari_leve==95:
            vari_vara=5.2
            vari_inva=4550
        elif vari_leve>95 and vari_leve<=97:
            vari_vara=6.5
            vari_inva=5785
        elif vari_leve==98:
            vari_vara=26
            vari_inva=24700
        elif vari_leve==99:
            vari_vara=93.6
            vari_inva=90948
        elif vari_leve==100:
            vari_vara=-111.6
            vari_inva=-112200
        elif vari_leve>100 and vari_leve<=105:
            vari_vara=3.6
            vari_inva=3000
        elif vari_leve>105 and vari_leve<=110:
            vari_vara=7.2
            vari_inva=6780
        elif vari_leve>110 and vari_leve<=115:
            vari_vara=12
            vari_inva=12060
        elif vari_leve>115 and vari_leve<=120:
            vari_vara=18
            vari_inva=18960
        elif vari_leve>120 and vari_leve<125:
            vari_vara=25.2
            vari_inva=27600
        elif vari_leve==125:
            vari_vara=2635.2
            vari_inva=3264000
    cons_slin=1000
    cons_inqu=-100
    para_ince=cons_inqu*vari_inva
    para_slop=cons_slin*vari_vara
    vari_erfv=int(para_slop*vari_leve+para_ince)
    return vari_erfv
    
def fun_crex_cele(flag_kstp,vari_lede,vari_levn,vari_eexp):
    vari_texp=0
    vari_teep=0
    for para_leve in range (vari_lede):
        vari_texp+=fun_cexp_vrfu(flag_kstp,para_leve)
    for para_leex in range (vari_levn):
        vari_teep+=fun_cexp_vrfu(flag_kstp,para_leex)
    vari_teep+=vari_eexp
    vari_rexp=vari_texp-vari_teep
    return vari_rexp,vari_teep #总需经验值 现有总经验值


#!/usr/bin/env python
# -*- coding: utf-8 -*-

'''
THIS FILE IS PART OF AZUR LANE TOOL LIB BY MATT BELFAST BROWN
setup.py - The core part of the Azur Lane Tool.

Author: Matt Belfast Brown 
E-mail:thedayofthedo@gmail.com
Creat Date:2021-07-10
Version Date:2022-01-21
Version:0.4.8

THIS PROGRAM IS FREE FOR EVERYONE,IS LICENSED UNDER GPL-3.0
YOU SHOULD HAVE RECEIVED A COPY OF GPL-3.0 LICENSE.

Copyright (C) 2021-2022 Matt Belfast Brown

This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program.  If not, see <http://www.gnu.org/licenses/>.
'''

from setuptools import setup, find_packages

setup(
    name = "AzurLaneToolLib",
    version = "0.4.8",
    keywords = ("pip","azur_lane", "tool"),
    description = "Tools lib for Azur Lane which game powered by ManJiu Shanghai",
    long_description = "The lib of Azur Lane Tools",
    license = "GPL-3.0 LICENSE",

    url = "http://belfast.xiaopangkj.space/azur_lane/",
    author = "Matt Belfast Brown",
    author_email = "thedayofthedo@gmail.com",

    packages = find_packages(),
    py_modules = ['AzurLaneToolLib.__init__','AzurLaneToolLib.mode.mode_BlP_Cal','AzurLaneToolLib.mode.mode_EXP_Cal','AzurLaneToolLib.mode.mode_KSN_Com',
    'AzurLaneToolLib.mode.mode_CME_Cal'],
    include_package_data = True,
    platforms = "any",
    zip_safe=True,
    install_requires = []
)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

'''
THIS FILE IS PART OF AZUR LANE TOOL BY MATT BELFAST BROWN
mode_FCS_Cal.py - The core mode of the Azur Lane Tool.

Author:Matt Belfast Brown 
Create Date:2021-07-10
Version Date:2022-01-21
Version:0.4.8
Mode Create Date:2020-05-27
Mode Date:2021-08-12
Mode Version:0.1.4

THIS PROGRAM IS FREE FOR EVERYONE,IS LICENSED UNDER GPL-3.0
YOU SHOULD HAVE RECEIVED A COPY OF GPL-3.0 LICENSE.

Copyright (C) 2021-2022 Matt Belfast Brown

This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program.  If not, see <http://www.gnu.org/licenses/>.
'''
'''
#define variable name
 variable-name chinese
 fun_sfks_fuca 函数-计算水面舰船油耗
 fun_smks_fuca 函数-计算潜艇油耗
 fun_bsdg_fuca 函数-计算基础满级油耗
 fun_smks_mfuc 函数-计算潜艇移动油耗
 vari_ksct     变量-舰船类别
 para_ksct     参数-舰船类别
 
 #
 DD：驱逐；CL：轻巡；CA：重巡；MN：浅水重炮舰；MT：维修舰；
 CVL：轻航；CV：航母；BC：战列巡洋舰；BB：战列舰 
 #
 
'''
#define import list
import math

#define function
def fun_bsdg_fuca(vari_ksct,vari_rare,vari_brea,vari_ksnm):
    if vari_ksct == 'DD':
        para_ksct = 0
    elif vari_ksct in ['CL','MN','MT']:
        para_ksct = 1
    elif vari_ksct in ['CA','CVL']:
        para_ksct = 2
    elif vari_ksct == 'CV':
        para_ksct = 3
    elif vari_ksct == 'BC':
        para_ksct = 4
    elif vari_ksct == 'BB':
        para_ksct = 5
    if vari_rare == '普通':
        para_raco = 0
    elif vari_rare == '稀有':
        para_raco = 1
    elif vari_rare == '精锐':
        para_raco = 2
    elif vari_rare in ['超稀有','最高方案']:
        para_raco = 3
    elif vari_rare in ['海上传奇','决战方案']:
        para_raco = 4
    if vari_brea == 0：
        para_brco = 0
    elif vari_brea == 1；
        para_brco = 2
    elif vari_brea == 2
        para_brco = 4
    elif vari_brea == 3:
        para_brco = 6
    vari_bofb=list_bofd[para_ksct]
    vari_raco=list_raco[para_raco]
    vari_brco=list_brco[para_brco]
    if 
    vari_bffu=vari
#define list
list_bofd=[1,2,3,4,5,6]
list_raco=[0,1,2,3,4]
list_brco=[0,2,4,6]
list_spco=[7,9]
list_scco=[-2,-1,1]